<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">

<!--
SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.

SPDX-License-Identifier: LGPL-3.0-or-later
-->

<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1454"/>
        <source>%1 is released under %2</source>
        <translation>%1 je izdana pod %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="869"/>
        <source>Black</source>
        <translation>Črna</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="872"/>
        <source>White</source>
        <translation>Bela</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="875"/>
        <source>Dark Gray</source>
        <translation>Temno siva</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="878"/>
        <source>Gray</source>
        <translation>Siva</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="881"/>
        <source>Light Gray</source>
        <translation>Svetlo siva</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="884"/>
        <source>Red</source>
        <translation>Rdeča</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="887"/>
        <source>Green</source>
        <translation>Zelena</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="890"/>
        <source>Blue</source>
        <translation>Modra</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="893"/>
        <source>Cyan</source>
        <translation>Cian</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="896"/>
        <source>Magenta</source>
        <translation>Škrlatna</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="899"/>
        <source>Yellow</source>
        <translation>Rumena</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="902"/>
        <source>Dark Red</source>
        <translation>Temno rdeča</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="905"/>
        <source>Dark Green</source>
        <translation>Temno zelena</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="908"/>
        <source>Dark Blue</source>
        <translation>Temno modra</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="911"/>
        <source>Dark Cyan</source>
        <translation>Temna cijan</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="914"/>
        <source>Dark Magenta</source>
        <translation>Temna škrlatna</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="917"/>
        <source>Dark Yellow</source>
        <translation>Temno rumena</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="30"/>
        <source>Confirm</source>
        <translation>Potrdi</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="97"/>
        <source>Enter a new shortcut</source>
        <translation>Določite novo bližnjico</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="593"/>
        <source>Stop reading</source>
        <translation>Zaustavi branje</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="595"/>
        <source>Text to Speech</source>
        <translation>Besedilo v govor</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="618"/>
        <source>Translate</source>
        <translation>Prevedi</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="640"/>
        <source>Speech To Text</source>
        <translation>Govor v besedilo</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="278"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1268"/>
        <source>Advanced</source>
        <translation>Napredno</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="301"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="302"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1647"/>
        <source>Print</source>
        <comment>button</comment>
        <translation>Tiskaj</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="318"/>
        <source>Basic</source>
        <translation>Osnovno</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="334"/>
        <source>Printer</source>
        <translation>Tiskalnik</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="350"/>
        <source>Copies</source>
        <translation>Kopije</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="372"/>
        <source>Page range</source>
        <translation>Obseg strani</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="375"/>
        <source>All</source>
        <translation>vse</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="376"/>
        <source>Current page</source>
        <translation>trenutna stran</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="377"/>
        <source>Select pages</source>
        <translation>izbor strani</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="397"/>
        <source>Orientation</source>
        <translation>Orientacija</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="422"/>
        <source>Portrait</source>
        <translation>pokončno</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="432"/>
        <source>Landscape</source>
        <translation>ležeče</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="460"/>
        <source>Pages</source>
        <translation>Strani</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="472"/>
        <source>Color mode</source>
        <translation>Barvni način</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="475"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1583"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1663"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1679"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1694"/>
        <source>Color</source>
        <translation type="vanished">Barvno</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="475"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1670"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1682"/>
        <source>Grayscale</source>
        <translation>Sivo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="487"/>
        <source>Margins</source>
        <translation>Robovi</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Narrow (mm)</source>
        <translation>Ozko (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Normal (mm)</source>
        <translation>Navadno (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Moderate (mm)</source>
        <translation>Zmerno (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Customize (mm)</source>
        <translation>Prilagodi (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="500"/>
        <source>Top</source>
        <translation>Zgoraj</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="503"/>
        <source>Left</source>
        <translation>Levo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="506"/>
        <source>Bottom</source>
        <translation>Spodaj</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="509"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="556"/>
        <source>Scaling</source>
        <translation>Povečava</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="573"/>
        <source>Actual size</source>
        <translation>Dejanska velikost</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="582"/>
        <source>Scale</source>
        <translation>Merilo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="613"/>
        <source>Paper</source>
        <translation>paipr</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="626"/>
        <source>Paper size</source>
        <translation>Velikost papirja</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="641"/>
        <source>Print Layout</source>
        <translation>Razporeditev tiskanja</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
        <source>Duplex</source>
        <translation>Dvostransko</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="668"/>
        <source>N-up printing</source>
        <translation>N-na list</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>2 pages/sheet, 1×2</source>
        <translation>2 strani/list, 1×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>4 pages/sheet, 2×2</source>
        <translation>4 strani/list, 2×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>6 pages/sheet, 2×3</source>
        <translation>6 strani/list, 2×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>9 pages/sheet, 3×3</source>
        <translation>9 strani/list, 3×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>16 pages/sheet, 4×4</source>
        <translation>16 strani/list, 4×4</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="683"/>
        <source>Layout direction</source>
        <translation>Smer razporejanja</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="727"/>
        <source>Page Order</source>
        <translation>Vrstni red strani</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="740"/>
        <source>Collate pages</source>
        <translation>Zbiraj strani</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="746"/>
        <source>Print pages in order</source>
        <translation>natisni strani po vrstnem redu</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Front to back</source>
        <translation>od prve do zadnje</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Back to front</source>
        <translation>od zadnje do prve</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="774"/>
        <source>Watermark</source>
        <translation>Vodni žig</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="788"/>
        <source>Add watermark</source>
        <translation>Dodaj vodni žig</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="834"/>
        <source>Text watermark</source>
        <translation>Besedilni vodni žig</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Confidential</source>
        <translation>Zaupno</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Draft</source>
        <translation>Osnutek</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Sample</source>
        <translation>Vzorec</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Custom</source>
        <translation>Prilagojeno</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="847"/>
        <source>Input your text</source>
        <translation>Vnesite besedilo</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="872"/>
        <source>Picture watermark</source>
        <translation>Slikovni vodni žig</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="896"/>
        <source>Layout</source>
        <translation>Razpored</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="899"/>
        <source>Tile</source>
        <translation>Razpostavi</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="899"/>
        <source>Center</source>
        <translation>Sredina</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="912"/>
        <source>Angle</source>
        <translation>Kot</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="931"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="955"/>
        <source>Transparency</source>
        <translation>Prosojnost</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1013"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2283"/>
        <source>Print to PDF</source>
        <translation>Tiskaj v PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1014"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2282"/>
        <source>Save as Image</source>
        <translation>Shrani kot sliko</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1264"/>
        <source>Collapse</source>
        <translation>Zloži</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1359"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1368"/>
        <source>Flip on short edge</source>
        <translation>Prelom na kratki stranici</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1298"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1363"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1367"/>
        <source>Flip on long edge</source>
        <translation>Prelom na dolgi stranici</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1461"/>
        <source>Input page numbers please</source>
        <translation>Vnesite strani</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1464"/>
        <source>Maximum page number reached</source>
        <translation>Doseženo je največje število strani</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1467"/>
        <source>Input English comma please</source>
        <translation>Vnesite angleško vejico</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1470"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation>Vnesite strani kot: 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1700"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2312"/>
        <source>*.pdf</source>
        <translation>*.pdf</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1770"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation>Na primer 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2312"/>
        <source>Save as PDF</source>
        <translation>Shrani kot PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2351"/>
        <source>Save as image</source>
        <translation>Shrani kot sliko</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2353"/>
        <source>Images</source>
        <translation>Slike</translation>
    </message>
    <message>
        <source>Full Color</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1590"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1593"/>
        <source>Confidential</source>
        <translation>Zaupno</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1608"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1611"/>
        <source>Draft</source>
        <translation>Osnutek</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1626"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1629"/>
        <source>Sample</source>
        <translation>Vzorec</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="286"/>
        <source>Search</source>
        <translation>iskanje</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="66"/>
        <source>Replace</source>
        <translation>Zamenjaj</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="68"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>Bližnjica je enaka kot %1. Kliknite na Dodaj, ta postane takoj aktivna</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="18"/>
        <source>Please input a new shortcut</source>
        <translation>Prosim, vnesite novo bližnjico</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="89"/>
        <source>None</source>
        <translation>Nič</translation>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="202"/>
        <source>Stop reading</source>
        <translation>zaustavi branje</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="204"/>
        <source>Text to Speech</source>
        <translation>Besedilo v govor</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="227"/>
        <source>Translate</source>
        <translation>Prevedi</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="249"/>
        <source>Speech To Text</source>
        <translation>Govor v besedilo</translation>
    </message>
</context>
<context>
    <name>DToolbarEditPanel</name>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="884"/>
        <source>Default toolset</source>
        <translation>Priveti nabor orodji</translation>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="915"/>
        <source>Drag your favorite items into the toolbar</source>
        <translation>Povlecite priljubljene predmete v orodno vrstico</translation>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="916"/>
        <source>Drag below items into the toolbar to restore defaults</source>
        <translation>Povlecite spodnje predmete v orodno vrstico, da povrnite privzeto</translation>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="921"/>
        <source>Confirm</source>
        <translation>Potrdi</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="94"/>
        <source>Color</source>
        <translation>Barvno</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="526"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiraj</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="529"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Izrezi</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="534"/>
        <source>Select All</source>
        <translation>Izberi vse</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1347"/>
        <source>No search result</source>
        <translation>Ni rezultatov iskanja</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="330"/>
        <source>Restore Defaults</source>
        <translation>Obnovi privzeto</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="108"/>
        <source>Version</source>
        <translation>Različica</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="110"/>
        <source>Features</source>
        <translation>Zmožnosti</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="122"/>
        <source>Homepage</source>
        <translation>Domača stran</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="124"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="126"/>
        <source>Acknowledgements</source>
        <translation>Zasluge</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="128"/>
        <location filename="../widgets/daboutdialog.cpp" line="393"/>
        <source>Sincerely appreciate the open-source software used.</source>
        <translation>Spoštujte odprtokodni program, ki ga uporabljate.</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="395"/>
        <source>open-source software</source>
        <translation>odprtkodni program</translation>
    </message>
    <message>
        <location filename="../widgets/dfeaturedisplaydialog.cpp" line="151"/>
        <source>Continue</source>
        <translation>Nadaljuj</translation>
    </message>
    <message>
        <location filename="../widgets/dfeaturedisplaydialog.cpp" line="175"/>
        <source>Learn More</source>
        <translation>Več o tem</translation>
    </message>
    <message>
        <location filename="../widgets/dlicensedialog.cpp" line="78"/>
        <source>Open-Source Software</source>
        <translation>Odprtkodni program</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="194"/>
        <source>Select All</source>
        <translation>Izberi vse</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="104"/>
        <source>Please enter a new shortcut</source>
        <translation>Prosim, vnesite novo bližnjico</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="634"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="636"/>
        <source>Light Theme</source>
        <translation>Svetla tema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="637"/>
        <source>Dark Theme</source>
        <translation>Temna tema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="638"/>
        <source>System Theme</source>
        <translation>Sistemska tema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="668"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="676"/>
        <source>Feedback</source>
        <translation>Odziv</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="683"/>
        <source>Custom toolbar</source>
        <translation>Orodna vrstica po meri</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="691"/>
        <source>About</source>
        <translation>O tem</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="698"/>
        <source>Exit</source>
        <translation>Izhod</translation>
    </message>
</context>
</TS>